@@ -66,7 +66,7 @@ session = None
 def encode_url(segments=None, annotations=None, coords=None, skeletons=None,
                seg_colors=None, invis_segs=None, dataset='production', scene=None,
                open_browser=False, to_clipboard=False, short=True):
-    """Encode data as flywire neuroglancer scene.
+    """Encode data as FlyWire neuroglancer scene.
 
     Parameters
     ----------
@@ -177,7 +177,8 @@ def encode_url(segments=None, annotations=None, coords=None, skeletons=None,
             seg_colors = dict(zip(all_segs, seg_colors))
 
         # Turn colors into hex
-        seg_colors = {s: mcl.to_hex(c) for s, c in seg_colors.items()}
+        # Also make sure keys are int (not np.int64)
+        seg_colors = {int(s): mcl.to_hex(c) for s, c in seg_colors.items()}
 
         # Assign colors
         scene['layers'][seg_layer_ix]['segmentColors'] = seg_colors
@@ -232,7 +233,7 @@ def add_skeleton_layer(x, scene):
     x :             navis.TreeNeuron | pymaid.CatmaidNeuron | int
                     Neuron to generate a URL for. Integers are interpreted as
                     CATMAID skeleton IDs. CatmaidNeurons will automatically be
-                    transformed to flywire coordinates. Neurons are expected to
+                    transformed to FlyWire coordinates. Neurons are expected to
                     be in nanometers and will be converted to voxels.
     scene :         dict
                     Scene to add annotation layer to.
@@ -438,11 +439,11 @@ def shorten_url(scene, refresh_session=False):
 
 
 def generate_open_ends_url(x):
-    """Generate a flywire URL with potential open ends for given neuron.
+    """Generate a FlyWire URL with potential open ends for given neuron.
 
     Parameters
     ----------
-    x :     flywire ID | navis.TreeNeuron | mesh
+    x :     root ID | navis.TreeNeuron | mesh
             ID of neuron to generate open ends for.
 
     """
