@@ -39,7 +39,8 @@ from .utils import (parse_volume, FLYWIRE_DATASETS, get_chunkedgraph_secret,
 __all__ = ['fetch_edit_history', 'fetch_leaderboard', 'locs_to_segments',
            'locs_to_supervoxels', 'skid_to_id', 'update_ids',
            'roots_to_supervoxels', 'supervoxels_to_roots',
-           'neuron_to_segments', 'is_latest_root']
+           'neuron_to_segments', 'is_latest_root', 'is_valid_root',
+           'is_valid_supervoxel']
 
 
 def fetch_leaderboard(days=7, by_day=False, progress=True, max_threads=4):
@@ -305,7 +306,12 @@ def supervoxels_to_roots(x, timestamp=None, batch_size=10_000,
 
     """
     # Make sure we are working with an array of integers
-    x = navis.utils.make_iterable(x).astype(np.int64, copy=False)
+    x = navis.utils.make_iterable(x)
+
+    # Check if IDs are valid (zeros are fine because we filter for them later on)
+    is_valid_supervoxel(x[(x != 0) & (x != '0')], raise_exc=True)
+
+    x = x.astype(np.int64, copy=False)
 
     # Parse the volume
     vol = parse_volume(dataset)
@@ -650,6 +656,9 @@ def is_latest_root(id, dataset='production', **kwargs):
     # The server doesn't like being asked for zeros
     not_zero = id != '0'
 
+    # Check if all other IDs are valid
+    is_valid_root(id[not_zero], raise_exc=True)
+
     is_latest = np.ones(len(id)).astype(bool)
 
     session = requests.Session()
@@ -669,26 +678,33 @@ def is_latest_root(id, dataset='production', **kwargs):
 
 def update_ids(id,
                sample=0.1,
+               supervoxels=None,
                dataset='production',
                progress=True, **kwargs):
     """Retrieve the most recent version of given FlyWire (root) ID(s).
 
     This function works by:
         1. Check if ID is outdated (see :func:`fafbseg.flywire.is_latest_root`)
-        2. See if we can map outdated IDs to a single up-to-date root (works
-           if neuron has only seen merges)
-        3. For uncertain IDs, fetch all supervoxels
-        3. Picking a random sample (see ``sample`` parameter) of supervoxels
-        4. Fetching the most recent root IDs for the sample supervoxels
-        5. Returning the root ID that was hit the most
+        2. If supervoxel provided, use it to update ID. Else try 3.
+        3. See if we can map outdated IDs to a single up-to-date root (works
+           if neuron has only seen merges). Else try 4.
+        4. For uncertain IDs, fetch all supervoxels and pick a random sample
+           (see ``sample`` parameter). Fetching the most recent root IDs for
+           the sample of supervoxels and return the root ID that was hit the
+           most often.
 
     Parameters
     ----------
-    id :            int | list-like
-                    Single ID or list of FlyWire (root) IDs.
+    id :            int | list-like | DataFrame
+                    Single ID or list of FlyWire (root) IDs. If DataFrame must
+                    contain either a `root_id` or `root` column and optionally
+                    a `supervoxel_id` or `supervoxel` column.
     sample :        int | float
                     Number (>= 1) or fraction (< 1) of super voxels to sample
                     to guess the most recent version.
+    supervoxels :   int | list-like, optional
+                    If provided will use these supervoxels to update ``id``
+                    instead of sampling across all supervoxels.
     dataset :       str | CloudVolume
                     Against which FlyWire dataset to query:
                       - "production" (current production dataset, fly_v31)
@@ -725,24 +741,65 @@ def update_ids(id,
 
     vol = parse_volume(dataset, **kwargs)
 
+    if isinstance(id, pd.DataFrame):
+        if isinstance(supervoxels, type(None)):
+            if 'supervoxel_id' in id.columns:
+                supervoxels = id['supervoxel_id'].values
+            elif 'supervoxel' in id.columns:
+                supervoxels = id['supervoxel'].values
+
+        if 'root_id' in id.columns:
+            id = id['root_id'].values
+        elif 'root' in id.columns:
+            id = id['root'].values
+        else:
+            raise ValueError('DataFrame must contain either `root_id` or '
+                             '`root` column.')
+
     if isinstance(id, (list, set, np.ndarray)):
         # Run is_latest once for all roots
         is_latest = is_latest_root(id, dataset=dataset)
-        res = [update_ids(x,
-                          dataset=dataset,
-                          is_latest=il,
-                          sample=sample) for x, il in navis.config.tqdm(zip(id, is_latest),
-                                                                        desc='Updating',
-                                                                        leave=False,
-                                                                        total=len(id),
-                                                                        disable=not progress or len(id) == 1)]
-        return pd.concat(res, axis=0, sort=False, ignore_index=True)
+        if isinstance(supervoxels, type(None)):
+            res = [update_ids(x,
+                              dataset=dataset,
+                              is_latest=il,
+                              supervoxels=None,
+                              sample=sample) for x, il, in navis.config.tqdm(zip(id, is_latest),
+                                                                               desc='Updating',
+                                                                               leave=False,
+                                                                               total=len(id),
+                                                                               disable=not progress or len(id) == 1)]
+            res = pd.concat(res, axis=0, sort=False, ignore_index=True)
+        else:
+            if (not isinstance(supervoxels, (list, set, np.ndarray))
+                or len(supervoxels) != len(id)):
+                raise ValueError(f'Number of supervoxels ({len(supervoxels)}) does '
+                                 f'not match number of root IDs ({len(id)})')
+            elif any(pd.isnull(supervoxels)):
+                raise ValueError('`supervoxels` must not contain `None`')
+            elif any(pd.isnull(id)):
+                raise ValueError('`id` must not contain `None`')
+
+            id = np.array(id).astype(int)
+
+            res = pd.DataFrame()
+            res['old_id'] = id
+            res['new_id'] = id
+            res.loc[~is_latest, 'new_id'] = supervoxels_to_roots(supervoxels[~is_latest],
+                                                                 dataset=dataset)
+            res['conf'] = 1
+            res['changed'] = res['new_id'] != res['old_id']
+        return res
 
     try:
         id = int(id)
     except ValueError:
-        raise ValueError(f'{id} does not look like a valid root ID.')
+        raise ValueError(f'"{id} does not look like a valid root ID.')
 
+    if id == 0 or pd.isnull(id):
+        navis.config.logger.warning(f'Unable to update ID "{id}" - returning '
+                                    'unchanged.')
+        return id
 
     # Check if outdated
     if isinstance(is_latest, type(None)):
@@ -755,11 +812,22 @@ def update_ids(id,
         if len(pot_roots) == 1:
             new_id = pot_roots[0]
             conf = 1
+        elif supervoxels:
+            try:
+                supervoxels = int(supervoxels)
+            except ValueError:
+                raise ValueError(f'"{supervoxels} does not look like a valid '
+                                 'supervoxel ID.')
+            new_id = client.chunkedgraph.get_root_id(supervoxels_to_roots)
+            conf = 1
         else:
             # Get supervoxel ids - we need to use mip=0 because otherwise small
             # neurons might not have any (visible) supervoxels
             svoxels = roots_to_supervoxels(id, progress=False)[int(id)]
 
+            # Note: instead of supervoxels we could also use higher level IDs
+            # (stop layer 3 or 4) which might be much faster
+
             # Shuffle voxels
             np.random.shuffle(svoxels)
 
@@ -1009,3 +1077,81 @@ def get_segmentation_cutout(bbox, dataset='production', root_ids=True,
             cutout[cutout == k] = v
 
     return cutout[:, :, :, 0], np.asarray(vol.scale['resolution']), offset_nm
+
+
+def is_valid_root(x, raise_exc=False, dataset='production'):
+    """Check if ID is (potentially) valid root ID.
+
+    Parameters
+    ----------
+    x :             int | str | iterable
+                    ID(s) to check.
+    raise_exc :     bool
+                    If True and any IDs are invalid will raise an error.
+                    Mostly for internal use.
+
+    Returns
+    -------
+    bool
+            If ``x`` is a single ID.
+    array
+            If ``x`` is iterable.
+
+    """
+    vol = parse_volume(dataset)
+
+    if navis.utils.is_iterable(x):
+        is_valid =  np.array([is_valid_root(r, dataset=vol) for r in x])
+        if raise_exc and not all(is_valid):
+            invalid = set(np.asarray(x)[~is_valid].tolist())
+            raise ValueError(f'Invalid root IDs found: {invalid}')
+        return is_valid
+
+    try:
+        is_valid = vol.get_chunk_layer(x) == 10
+    except:
+        is_valid = False
+
+    if raise_exc and not is_valid:
+        raise ValueError(f'{x} is not a valid root ID')
+
+    return is_valid
+
+
+def is_valid_supervoxel(x, raise_exc=False, dataset='production'):
+    """Check if ID is (potentially) valid supervoxel ID.
+
+    Parameters
+    ----------
+    x :             int | str | iterable
+                    ID(s) to check.
+    raise_exc :     bool
+                    If True and any IDs are invalid will raise an error.
+                    Mostly for internal use.
+
+    Returns
+    -------
+    bool
+            If ``x`` is a single ID.
+    array
+            If ``x`` is iterable.
+
+    """
+    vol = parse_volume(dataset)
+
+    if navis.utils.is_iterable(x):
+        is_valid =  np.array([is_valid_supervoxel(r, dataset=vol) for r in x])
+        if raise_exc and not all(is_valid):
+            invalid = set(np.asarray(x)[~is_valid].tolist())
+            raise ValueError(f'Invalid supervoxel IDs found: {invalid}')
+        return is_valid
+
+    try:
+        is_valid = vol.get_chunk_layer(x) == 1
+    except:
+        is_valid = False
+
+    if raise_exc and not is_valid:
+        raise ValueError(f'{x} is not a valid supervoxel ID')
+
+    return is_valid
