@@ -16,5 +16,5 @@
 """Module containing functions to interact with Google segmentation."""
 
 from .meshes import *
-from .search import *
 from .segmentation import *
+from .synapses import *
